====================
API - LTE Status LED
====================

.. module:: lannerpsp.sdk_sled_lte

.. currentmodule:: lannerpsp

Regular Classes
===============

The following classes are intended for general use with the devices they
represent. All classes in this section are concrete (not abstract).

LTEStatusLED
------------

.. autoclass:: LTEStatusLED
    :members: off, red, red_blink, green, green_blink, yellow, yellow_blink, test

Supported Platforms
===================

The following platforms have been verified and confirmed to be supported:

* `LEC-7242`_

.. _LEC-7242: https://lannerinc.com/products/intelligent-edge-appliances/embedded-platform/lec-7242
